@@ -331,11 +331,11 @@ LWP::Authen::OAuth2 - Make requests to OAuth2 APIs.
 
 =head1 VERSION
 
-Version 0.13
+Version 0.15
 
 =cut
 
-our $VERSION = '0.14';
+our $VERSION = '0.16';
 
 
 =head1 SYNOPSIS
@@ -385,6 +385,12 @@ L<LWP::Authen::OAuth2::ServiceProvider::Strava>
 
 implemented by L<Leon Wright|https://github.com/techman83>
 
+=item * Yahoo
+
+L<LWP::Authen::OAuth2::ServiceProvider::Yahoo>
+
+implemented by L<Michael Stevens|https://github.com/michael-stevens>
+
 =back
 
 You can also access any other OAuth2 service by setting up a plain C<LWP::Authen::OAuth2> object. If you do, and the service provider might be of interest to other people, please submit a patch so we can include it in this distribution, or release it as a standalone package.
@@ -832,7 +838,7 @@ You can also look for information at:
 
 =item Github (submit patches here)
 
-L<https://github.com/btilly/perl-oauth2>
+L<https://github.com/domm/perl-oauth2>
 
 =item RT: CPAN's request tracker (report bugs here)
 
@@ -846,9 +852,9 @@ L<http://annocpan.org/dist/LWP-Authen-OAuth2>
 
 L<http://cpanratings.perl.org/d/LWP-Authen-OAuth2>
 
-=item Search CPAN
+=item MetaCPAN
 
-L<http://search.cpan.org/dist/LWP-Authen-OAuth2/>
+L<https://metacpan.org/release/LWP-Authen-OAuth2>
 
 =back
 
@@ -879,6 +885,8 @@ C<ServiceProvider> work without requiring subclassing.
 
 =item * L<Adam Millerchip|https://github.com/amillerchip> for adding a L<Line | https://line.me> Service Provider and some refactoring
 
+=item * L<Michael Stevens|https://github.com/mstevens> for adding a C<Yahoo | https://developer.yahoo.com> Service Provider and some dist cleanup
+
 =item * Nick Morrott for fixing some documentation typos
 
 =back
